/*
Pluck: an open source trivia game for Android

Copyright (C) 2021 Joguitos do luca0N!

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, either version 3 of the License, or (at your option) any later
version.

This program is distributed in the hope that it will be useful, but WITHOUT
ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.

This game is a fork of LibreTrivia, and its source code is available at
<https://github.com/tryton-vanmeer/LibreTrivia>.

Contact us at <joguitos+pluck@luca0n.com>.
*/

package com.luca0n.joguitos.pluck.util;

import android.content.Context;
import android.content.SharedPreferences;
import android.preference.PreferenceManager;

import com.luca0n.joguitos.pluck.R;

public class UiUtil {
	/**
	 * Applies the theme selected by the user to the context.
	 * @param context The activity context.
	 * @since 2021-03-17
	 */
	public static void setTheme(Context context){
		SharedPreferences s = PreferenceManager.getDefaultSharedPreferences(context.getApplicationContext());

		String dark = context.getString(R.string.pref_ui_theme_entryValues_dark),
					theme = getTheme(context);

		if (theme.equals(dark))
			context.setTheme(R.style.AppTheme_Dark);
		else
			context.setTheme(R.style.AppTheme);
	}

	/**
	 * @return The app theme selected by the user.
	 * @param context The activity context.
	 * @since 2021-03-17
	 */
	public static String getTheme(Context context){
		SharedPreferences s = PreferenceManager.getDefaultSharedPreferences(context.getApplicationContext());
		String themeKey = context.getString(R.string.pref_ui_theme),
					 themeLight = context.getString(R.string.pref_ui_theme_entryValues_light);
		return s.getString(themeKey, themeLight);
	}
}
